Computes the Breslow estimator of the baseline hazard function for a proportional hazard regression model - only for censored survival data.
Usage
baseline_hazard(surv_times, delta, coxph_preds, eval_times=NULL, smooth=FALSE,
cumulative=TRUE)Arguments
- surv_times
the survival times - an atomic vector of doubles
- delta
the censoring indicator - a vector same length as surv_times
- coxph_preds
the predicted values of the regression model on the log hazard scale
- eval_times
values at which the baseline hazard will be evaluated
- smooth
if
TRUEbaseline_hazardwill smooth the estimated baseline hazard using Friedman's super smoothersupsmu- cumulative
if
TRUEthe cumulative survival function will be computed
Value
a vector of length equal to the length of surv_times (or of length
eval_times if eval_times is not NULL) containing the baseline
hazard evaluated at t (or at eval_times if eval_times is not
NULL). If cumulative is set to TRUE then the returned
vector evaluates the cumulative hazard function at those values.
Details
The proportional hazard model assumes h(t|x)=lambda(t)*exp(f(x)).
gbmt can estimate the f(x) component via partial likelihood.
After estimating f(x), baseline_hazard can compute a nonparametric
estimate of lambda(t).
References
N. Breslow (1972). "Discussion of `Regression Models and Life-Tables' by D.R. Cox," Journal of the Royal Statistical Society, Series B, 34(2):216-217.
N. Breslow (1974). "Covariance analysis of censored survival data," Biometrics 30:89-99.
Author
James Hickey, Greg Ridgeway gregridgeway@gmail.com