Skip to contents

Creation methods that take an empty distribution object and builds on top of the skeleton.

Usage

create_dist(empty_obj, ...)

Arguments

empty_obj

An empty distribution object of the correct class.

...

extra parameters used to define the distribution object, see gbm_dist.

Value

an appropriated gbm distribution object

Author

James Hickey