Estimates optimal number of boosting iterations given a
GBMFit object and optionally plots various performance
measures.
Arguments
- object
a
GBMFitobject created from an initial call togbmtorgbm.- plot.it
an indicator of whether or not to plot the performance measures. Setting
plot.it=TRUEcreates two plots. The first plot plots the train error (in black) and the validation error (in red) versus the iteration number. The scale of the error measurement, shown on the left vertical axis, depends on thedistributionargument used in the initial call.- oobag.curve
indicates whether to plot the out-of-bag performance measures in a second plot.
- overlay
if TRUE and oobag.curve=TRUE then a right y-axis is added to the training and test error plot and the estimated cumulative improvement in the loss function is plotted versus the iteration number.
- method
indicate the method used to estimate the optimal number of boosting iterations.
method="OOB"computes the out-of-bag estimate andmethod="test"uses the test (or validation) dataset to compute an out-of-sample estimate.method="cv"extracts the optimal number of iterations using cross-validation ifgbmwas called withcv.folds>1.- main
the main title for the plot. Defaults to
main = "".
Value
gbm.perf returns the estimated optimal number of iterations.
The method of computation depends on the method argument.