gbmt uses openmp to parallelize its core algorithm, and the
details are controlled by this object. As guidance, set
num_threads to the number of cores on your computer, and set
array_chunk_size to a reasonable - not necessarily small -
size.
Arguments
- num_threads
the number of threads to use (a positive integer). The number of cores on your computer is a reasonable default.
- array_chunk_size
the size of chunks to use in array scans. Values that are too small result in a great deal of overhead; The default of 1024 appears reasonable, but do experiment.