Method to perform additional boosting using a GBMFit object
- does not support further cross validation.
Usage
gbm_more(
gbm_fit_obj,
num_new_trees = 100,
data = NULL,
weights = NULL,
offset = NULL,
is_verbose = FALSE
)Arguments
- gbm_fit_obj
a
GBMFitobject produced usinggbmt. This object describes the boosted model on which to perform additional boosting.- num_new_trees
a positive integer specifying how many additional iterations to perform. This has a default value of
100.- data
a
data.frameormatrixcontaining the new values for the predictor and response variables for the additional iterations. The names of the variables must match those appearing in the original fit (as well as the number of rows), and this value defaults toNULL. With a value ofNULLthe original data may be used for the additional boosting, if no original or new data is specified an error will be thrown.- weights
an atomic vector of doubles specifying the importance of each row of the
datain the additional iterations. If the previous data used is kept withingbm_fit_obj; then the weights are extracted from the storedGBMDataobject.- offset
an atomic vector of doubles specifying the offset for each response value in the data used for additional boosting.
- is_verbose
a logical specifying whether or not the additional fitting should run "noisely" with feedback on progress provided to the user.