Additional performance using appropriate metric for pairwise distribution fit.
Arguments
- y
responses used for fit.
- f
the predicted responses.
- group
the indices specifiying which response variables belong to which groups.
- metric
What type of performance measure to compute in
perf_pairwise. Can take values "ir_measure_conc", "ir_measure_mrr", "ir_measure_map" or "ir_measure_ndgc".- w
is the weights of each observation.
- max_rank
the maximum rank considered in the groups measure.
Author
Greg Ridgeway gregridgeway@gmail.com