Relative influence via permutation
Source:R/permutation-relative-influence.r
permutation_relative_influence.RdThis function offers a method for computing the relative influence in
summary.GBMFit, and is not intended to be called directly.
Arguments
- gbm_fit_obj
a
GBMFitobject from an initial call togbmt.- num_trees
the number of trees to use for computations. If not provided, the function will guess: if a test set was used in fitting, the number of trees resulting in lowest test set error will be used; otherwise, if cross-validation was performed, the number of trees resulting in lowest cross-validation error will be used; otherwise, all trees will be used.
- rescale
whether or not the result should be scaled. Defaults to
FALSE.- sort_it
whether or not the results should be (reverse) sorted. Defaults to
FALSE.
Value
By default, returns an unprocessed vector of estimated
relative influences. If the rescale and sort
arguments are used, returns a processed version of the same.
Details
Calculates the relative influence of predictors via random
permutation of each predictor one at a time and calculating the
associated reduction in predictive performance. This experimental
measure is similar to the variable importance measures Breiman uses
for random forests, but gbmt currently computes using
the entire training dataset (not the out-of-bag observations).
Author
Greg Ridgeway gregridgeway@gmail.com