Plots the marginal effect of the selected variables by "integrating" out the other variables.
Usage
# S3 method for class 'GBMFit'
plot(
x,
var_index = 1,
num_trees = gbm_fit_obj$params$num_trees,
continuous_resolution = 100,
grid_levels = NULL,
return_grid = FALSE,
type = "link",
...
)Arguments
- x
a
GBMFitobject fitted using a call togbmt- var_index
a vector of indices or the names of the variables to plot. If using indices, the variables are indexed in the same order that they appear in the initial
gbmtformula. Iflength(var_index)is between 1 and 3 thenplot.GBMFitproduces the plots. Otherwise,plot.GBMFitreturns only the grid of evaluation points and their average predictions- num_trees
the number of trees used to generate the plot. Only the first
num_treestrees will be used- continuous_resolution
The number of equally space points at which to evaluate continuous predictors
- grid_levels
A list containing the points at which to evaluate each predictor in
var_index(in the same order asvar_index). For continuous predictors this is usually a regular sequence of values within the range of the variable. For categorical predictors, the points are the levels of the factor. Whenlength(var_index)is one, the values can be provided directly, outside a list. This is NULL by default and generated automatically from the data, usingcontinuous_resolutionfor continuous predictors. Forcing the values can be useful to evaluate two models on the same exact range- return_grid
if
TRUEthenplot.GBMFitproduces no graphics and only returns the grid of evaluation points and their average predictions. This is useful for customizing the graphics for special variable types or for dimensions greater than 3- type
the type of prediction to plot on the vertical axis. See
predict_gmt- ...
other arguments passed to the plot function
Value
Nothing unless return_grid is true then
plot.GBMFit produces no graphics and only returns the grid of
evaluation points and their average predictions.
Details
plot.GBMFit produces low dimensional projections of the
GBMFit object, see gbmt, by integrating out
the variables not included in the var_index argument. The
function selects a grid of points and uses the weighted tree
traversal method described in Friedman (2001) to do the
integration. Based on the variable types included in the
projection, plot_gbmt selects an appropriate display
choosing amongst line plots, contour plots, and
lattice plots. If the default graphics are
not sufficient the user may set return.grid=TRUE, store the
result of the function, and develop another graphic display more
appropriate to the particular example.