The train and validation error (in black and red respectively) are plotted against the iteration number. If the initial model was built with cross-validation, the cross-validation error is shown in green.
Usage
# S3 method for class 'GBMTPerformance'
plot(x, out_of_bag_curve = FALSE, overlay = TRUE, main = "", ...)Arguments
- x
a
GBMTPerformanceobject (created bygbmt_performance)- out_of_bag_curve
indicates whether to plot the out-of-bag performance measures in a second plot.
- overlay
if TRUE and out_of_bag_curve=TRUE then a right y-axis is added to the training and test error plot and the estimated cumulative improvement in the loss function is plotted versus the iteration number.
- main
the main title for the plot.
- ...
currently ignored
Details
The scale of the error measurement, shown on the
left vertical axis, depends on the distribution argument
used in the initial call to gbmt.