Skip to contents

Marks the quantiles on the axes of the current plot.

Usage

quantile_rug(x, prob = (0:10)/10, ...)

Arguments

x

a numeric vector.

prob

the quantiles of x to mark on the x-axis.

...

additional graphics parameters currently ignored.

Value

No return values

See also

Author

Greg Ridgeway gregridgeway@gmail.com

Examples


x <- rnorm(100)
y <- rnorm(100)
plot(x,y)
quantile_rug(x)