Creation methods that take an empty distribution object and builds on top of the skeleton.
Arguments
- empty_obj
An empty distribution object of the correct class.
- ...
extra parameters used to define the distribution object, see
gbm_dist.
Creation methods that take an empty distribution object and builds on top of the skeleton.
An empty distribution object of the correct class.
extra parameters used to define the distribution object,
see gbm_dist.