Calculate predictions from cross validated generalized boosting model from gbm2.
Usage
# S3 method for class 'GBMCVFit'
predict(object, gbm_data_obj, cv_folds, cv_group, best_iter_cv, ...)Arguments
- object
a GBMCVFit object containing CV gbm models
- gbm_data_obj
a GBMData object containing all of the data used to fit a gbm model.
- cv_folds
a positive integer specifying the number of folds to be used in cross-validation of the gbm fit.
- cv_group
vector of integers specifying which row of data belongs to which cv_fold.
- best_iter_cv
number of trees with the smallest cv error
- ...
not currently used